Class: Aws::MigrationHub::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHub::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhub/client.rb,
sig/client.rbs
Overview
An API client for MigrationHub. To construct a client, you need to configure a :region and :credentials.
client = Aws::MigrationHub::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateCreatedArtifactResponseSuccess, _AssociateDiscoveredResourceResponseSuccess, _AssociateSourceResourceResponseSuccess, _CreateProgressUpdateStreamResponseSuccess, _DeleteProgressUpdateStreamResponseSuccess, _DescribeApplicationStateResponseSuccess, _DescribeMigrationTaskResponseSuccess, _DisassociateCreatedArtifactResponseSuccess, _DisassociateDiscoveredResourceResponseSuccess, _DisassociateSourceResourceResponseSuccess, _ImportMigrationTaskResponseSuccess, _ListApplicationStatesResponseSuccess, _ListCreatedArtifactsResponseSuccess, _ListDiscoveredResourcesResponseSuccess, _ListMigrationTaskUpdatesResponseSuccess, _ListMigrationTasksResponseSuccess, _ListProgressUpdateStreamsResponseSuccess, _ListSourceResourcesResponseSuccess, _NotifyApplicationStateResponseSuccess, _NotifyMigrationTaskStateResponseSuccess, _PutResourceAttributesResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_created_artifact(params = {}) ⇒ Struct
Associates a created artifact of an AWS cloud resource, the target receiving the migration, with the migration task performed by a migration tool.
-
#associate_discovered_resource(params = {}) ⇒ Struct
Associates a discovered resource ID from Application Discovery Service with a migration task.
-
#associate_source_resource(params = {}) ⇒ Struct
Associates a source resource with a migration task.
-
#create_progress_update_stream(params = {}) ⇒ Struct
Creates a progress update stream which is an AWS resource used for access control as well as a namespace for migration task names that is implicitly linked to your AWS account.
-
#delete_progress_update_stream(params = {}) ⇒ Struct
Deletes a progress update stream, including all of its tasks, which was previously created as an AWS resource used for access control.
-
#describe_application_state(params = {}) ⇒ Types::DescribeApplicationStateResult
Gets the migration status of an application.
-
#describe_migration_task(params = {}) ⇒ Types::DescribeMigrationTaskResult
Retrieves a list of all attributes associated with a specific migration task.
-
#disassociate_created_artifact(params = {}) ⇒ Struct
Disassociates a created artifact of an AWS resource with a migration task performed by a migration tool that was previously associated.
-
#disassociate_discovered_resource(params = {}) ⇒ Struct
Disassociate an Application Discovery Service discovered resource from a migration task.
-
#disassociate_source_resource(params = {}) ⇒ Struct
Removes the association between a source resource and a migration task.
-
#import_migration_task(params = {}) ⇒ Struct
Registers a new migration task which represents a server, database, etc., being migrated to AWS by a migration tool.
-
#list_application_states(params = {}) ⇒ Types::ListApplicationStatesResult
Lists all the migration statuses for your applications.
-
#list_created_artifacts(params = {}) ⇒ Types::ListCreatedArtifactsResult
Lists the created artifacts attached to a given migration task in an update stream.
-
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResult
Lists discovered resources associated with the given
MigrationTask. -
#list_migration_task_updates(params = {}) ⇒ Types::ListMigrationTaskUpdatesResult
This is a paginated API that returns all the migration-task states for the specified
MigrationTaskNameandProgressUpdateStream. -
#list_migration_tasks(params = {}) ⇒ Types::ListMigrationTasksResult
Lists all, or filtered by resource name, migration tasks associated with the user account making this call.
-
#list_progress_update_streams(params = {}) ⇒ Types::ListProgressUpdateStreamsResult
Lists progress update streams associated with the user account making this call.
-
#list_source_resources(params = {}) ⇒ Types::ListSourceResourcesResult
Lists all the source resource that are associated with the specified
MigrationTaskNameandProgressUpdateStream. -
#notify_application_state(params = {}) ⇒ Struct
Sets the migration state of an application.
-
#notify_migration_task_state(params = {}) ⇒ Struct
Notifies Migration Hub of the current status, progress, or other detail regarding a migration task.
-
#put_resource_attributes(params = {}) ⇒ Struct
Provides identifying details of the resource being migrated so that it can be associated in the Application Discovery Service repository.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1556 1557 1558 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1556 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1559 1560 1561 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1559 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_created_artifact(params = {}) ⇒ Struct
Associates a created artifact of an AWS cloud resource, the target receiving the migration, with the migration task performed by a migration tool. This API has the following traits:
-
Migration tools can call the
AssociateCreatedArtifactoperation to indicate which AWS artifact is associated with a migration task. -
The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example:
arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b. -
Examples of the AWS resource behind the created artifact are, AMI's, EC2 instance, or DMS endpoint, etc.
86 |
# File 'sig/client.rbs', line 86
def associate_created_artifact: (
|
#associate_discovered_resource(params = {}) ⇒ Struct
Associates a discovered resource ID from Application Discovery Service with a migration task.
101 |
# File 'sig/client.rbs', line 101
def associate_discovered_resource: (
|
#associate_source_resource(params = {}) ⇒ Struct
Associates a source resource with a migration task. For example, the source resource can be a source server, an application, or a migration wave.
116 |
# File 'sig/client.rbs', line 116
def associate_source_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1529 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHub') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhub' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#create_progress_update_stream(params = {}) ⇒ Struct
Creates a progress update stream which is an AWS resource used for access control as well as a namespace for migration task names that is implicitly linked to your AWS account. It must uniquely identify the migration tool as it is used for all updates made by the tool; however, it does not need to be unique for each AWS account because it is scoped to the AWS account.
132 |
# File 'sig/client.rbs', line 132
def create_progress_update_stream: (
|
#delete_progress_update_stream(params = {}) ⇒ Struct
Deletes a progress update stream, including all of its tasks, which was previously created as an AWS resource used for access control. This API has the following traits:
-
The only parameter needed for
DeleteProgressUpdateStreamis the stream name (same as aCreateProgressUpdateStreamcall). -
The call will return, and a background process will asynchronously delete the stream and all of its resources (tasks, associated resources, resource attributes, created artifacts).
-
If the stream takes time to be deleted, it might still show up on a
ListProgressUpdateStreamscall. -
CreateProgressUpdateStream,ImportMigrationTask,NotifyMigrationTaskState, and all Associate[*] APIs related to the tasks belonging to the stream will throw "InvalidInputException" if the stream of the same name is in the process of being deleted. -
Once the stream and all of its resources are deleted,
CreateProgressUpdateStreamfor a stream of the same name will succeed, and that stream will be an entirely new logical resource (without any resources associated with the old stream).
142 |
# File 'sig/client.rbs', line 142
def delete_progress_update_stream: (
|
#describe_application_state(params = {}) ⇒ Types::DescribeApplicationStateResult
Gets the migration status of an application.
154 |
# File 'sig/client.rbs', line 154
def describe_application_state: (
|
#describe_migration_task(params = {}) ⇒ Types::DescribeMigrationTaskResult
Retrieves a list of all attributes associated with a specific migration task.
164 |
# File 'sig/client.rbs', line 164
def describe_migration_task: (
|
#disassociate_created_artifact(params = {}) ⇒ Struct
Disassociates a created artifact of an AWS resource with a migration task performed by a migration tool that was previously associated. This API has the following traits:
-
A migration user can call the
DisassociateCreatedArtifactsoperation to disassociate a created AWS Artifact from a migration task. -
The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example:
arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b. -
Examples of the AWS resource behind the created artifact are, AMI's, EC2 instance, or RDS instance, etc.
174 |
# File 'sig/client.rbs', line 174
def disassociate_created_artifact: (
|
#disassociate_discovered_resource(params = {}) ⇒ Struct
Disassociate an Application Discovery Service discovered resource from a migration task.
186 |
# File 'sig/client.rbs', line 186
def disassociate_discovered_resource: (
|
#disassociate_source_resource(params = {}) ⇒ Struct
Removes the association between a source resource and a migration task.
198 |
# File 'sig/client.rbs', line 198
def disassociate_source_resource: (
|
#import_migration_task(params = {}) ⇒ Struct
Registers a new migration task which represents a server, database, etc., being migrated to AWS by a migration tool.
This API is a prerequisite to calling the NotifyMigrationTaskState
API as the migration tool must first register the migration task with
Migration Hub.
210 |
# File 'sig/client.rbs', line 210
def import_migration_task: (
|
#list_application_states(params = {}) ⇒ Types::ListApplicationStatesResult
Lists all the migration statuses for your applications. If you use the
optional ApplicationIds parameter, only the migration statuses for
those applications will be returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
223 |
# File 'sig/client.rbs', line 223
def list_application_states: (
|
#list_created_artifacts(params = {}) ⇒ Types::ListCreatedArtifactsResult
Lists the created artifacts attached to a given migration task in an update stream. This API has the following traits:
-
Gets the list of the created artifacts while migration is taking place.
-
Shows the artifacts created by the migration tool that was associated by the
AssociateCreatedArtifactAPI. -
Lists created artifacts in a paginated interface.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
236 |
# File 'sig/client.rbs', line 236
def list_created_artifacts: (
|
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResult
Lists discovered resources associated with the given MigrationTask.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
250 |
# File 'sig/client.rbs', line 250
def list_discovered_resources: (
|
#list_migration_task_updates(params = {}) ⇒ Types::ListMigrationTaskUpdatesResult
This is a paginated API that returns all the migration-task states for
the specified MigrationTaskName and ProgressUpdateStream.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
264 |
# File 'sig/client.rbs', line 264
def list_migration_task_updates: (
|
#list_migration_tasks(params = {}) ⇒ Types::ListMigrationTasksResult
Lists all, or filtered by resource name, migration tasks associated with the user account making this call. This API has the following traits:
-
Can show a summary list of the most recent migration tasks.
-
Can show a summary list of migration tasks associated with a given discovered resource.
-
Lists migration tasks in a paginated interface.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
278 |
# File 'sig/client.rbs', line 278
def list_migration_tasks: (
|
#list_progress_update_streams(params = {}) ⇒ Types::ListProgressUpdateStreamsResult
Lists progress update streams associated with the user account making this call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
291 |
# File 'sig/client.rbs', line 291
def list_progress_update_streams: (
|
#list_source_resources(params = {}) ⇒ Types::ListSourceResourcesResult
Lists all the source resource that are associated with the specified
MigrationTaskName and ProgressUpdateStream.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
303 |
# File 'sig/client.rbs', line 303
def list_source_resources: (
|
#notify_application_state(params = {}) ⇒ Struct
Sets the migration state of an application. For a given application
identified by the value passed to ApplicationId, its status is set
or updated by passing one of three values to Status: NOT_STARTED | IN_PROGRESS | COMPLETED.
315 |
# File 'sig/client.rbs', line 315
def notify_application_state: (
|
#notify_migration_task_state(params = {}) ⇒ Struct
Notifies Migration Hub of the current status, progress, or other detail regarding a migration task. This API has the following traits:
-
Migration tools will call the
NotifyMigrationTaskStateAPI to share the latest progress and status. -
MigrationTaskNameis used for addressing updates to the correct target. -
ProgressUpdateStreamis used for access control and to provide a namespace for each migration tool.
327 |
# File 'sig/client.rbs', line 327
def notify_migration_task_state: (
|
#put_resource_attributes(params = {}) ⇒ Struct
Provides identifying details of the resource being migrated so that it
can be associated in the Application Discovery Service repository.
This association occurs asynchronously after PutResourceAttributes
returns.
-
Keep in mind that subsequent calls to PutResourceAttributes will override previously stored attributes. For example, if it is first called with a MAC address, but later, it is desired to add an IP address, it will then be required to call it with both the IP and MAC addresses to prevent overriding the MAC address.
-
Note the instructions regarding the special use case of the
ResourceAttributeListparameter when specifying any "VM" related value.
ListDiscoveredResources.
345 |
# File 'sig/client.rbs', line 345
def put_resource_attributes: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1549 1550 1551 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1549 def waiter_names [] end |