Class: Aws::MigrationHub::Types::AssociateDiscoveredResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-migrationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#discovered_resourceTypes::DiscoveredResource

Object representing a Resource.



107
108
109
110
111
112
113
114
# File 'lib/aws-sdk-migrationhub/types.rb', line 107

class AssociateDiscoveredResourceRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :discovered_resource,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call.



107
108
109
110
111
112
113
114
# File 'lib/aws-sdk-migrationhub/types.rb', line 107

class AssociateDiscoveredResourceRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :discovered_resource,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#migration_task_nameString

The identifier given to the MigrationTask. *Do not store personal data in this field.*



107
108
109
110
111
112
113
114
# File 'lib/aws-sdk-migrationhub/types.rb', line 107

class AssociateDiscoveredResourceRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :discovered_resource,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#progress_update_streamString

The name of the ProgressUpdateStream.



107
108
109
110
111
112
113
114
# File 'lib/aws-sdk-migrationhub/types.rb', line 107

class AssociateDiscoveredResourceRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :discovered_resource,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end