Class: Aws::MigrationHub::Types::ImportMigrationTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-migrationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call.



460
461
462
463
464
465
466
# File 'lib/aws-sdk-migrationhub/types.rb', line 460

class ImportMigrationTaskRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#migration_task_nameString

Unique identifier that references the migration task. *Do not store personal data in this field.*



460
461
462
463
464
465
466
# File 'lib/aws-sdk-migrationhub/types.rb', line 460

class ImportMigrationTaskRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#progress_update_streamString

The name of the ProgressUpdateStream. &gt;



460
461
462
463
464
465
466
# File 'lib/aws-sdk-migrationhub/types.rb', line 460

class ImportMigrationTaskRequest < Struct.new(
  :progress_update_stream,
  :migration_task_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end