Class: Aws::MigrationHub::Types::ListCreatedArtifactsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MigrationHub::Types::ListCreatedArtifactsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-migrationhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of results to be returned per page.
-
#migration_task_name ⇒ String
Unique identifier that references the migration task.
-
#next_token ⇒ String
If a
NextTokenwas returned by a previous call, there are more results available. -
#progress_update_stream ⇒ String
The name of the ProgressUpdateStream.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of results to be returned per page.
565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 565 class ListCreatedArtifactsRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#migration_task_name ⇒ String
Unique identifier that references the migration task. Do not store personal data in this field.
565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 565 class ListCreatedArtifactsRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If a NextToken was returned by a previous call, there are more
results available. To retrieve the next page of results, make the
call again using the returned token in NextToken.
565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 565 class ListCreatedArtifactsRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#progress_update_stream ⇒ String
The name of the ProgressUpdateStream.
565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 565 class ListCreatedArtifactsRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |