Class: Aws::MigrationHub::Types::ListDiscoveredResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MigrationHub::Types::ListDiscoveredResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-migrationhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results returned per page.
-
#migration_task_name ⇒ String
The name of the MigrationTask.
-
#next_token ⇒ String
If a
NextTokenwas returned by a previous call, there are more results available. -
#progress_update_stream ⇒ String
The name of the ProgressUpdateStream.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results returned per page.
615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 615 class ListDiscoveredResourcesRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#migration_task_name ⇒ String
The name of the MigrationTask. *Do not store personal data in this field.*
615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 615 class ListDiscoveredResourcesRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken.
615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 615 class ListDiscoveredResourcesRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#progress_update_stream ⇒ String
The name of the ProgressUpdateStream.
615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 615 class ListDiscoveredResourcesRequest < Struct.new( :progress_update_stream, :migration_task_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |