Class: Aws::MigrationHub::Types::ListMigrationTaskUpdatesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-migrationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#migration_task_update_listArray<Types::MigrationTaskUpdate>

The list of migration-task updates.

Returns:



702
703
704
705
706
707
# File 'lib/aws-sdk-migrationhub/types.rb', line 702

class ListMigrationTaskUpdatesResult < Struct.new(
  :next_token,
  :migration_task_update_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response includes a NextToken value, that means that there are more results available. The value of NextToken is a unique pagination token for each page. To retrieve the next page of results, call this API again and specify this NextToken value in the request. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.

Returns:

  • (String)


702
703
704
705
706
707
# File 'lib/aws-sdk-migrationhub/types.rb', line 702

class ListMigrationTaskUpdatesResult < Struct.new(
  :next_token,
  :migration_task_update_list)
  SENSITIVE = []
  include Aws::Structure
end