Class: Aws::MigrationHub::Types::ListMigrationTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MigrationHub::Types::ListMigrationTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-migrationhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Value to specify how many results are returned per page.
-
#next_token ⇒ String
If a
NextTokenwas returned by a previous call, there are more results available. -
#resource_name ⇒ String
Filter migration tasks by discovered resource name.
Instance Attribute Details
#max_results ⇒ Integer
Value to specify how many results are returned per page.
725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 725 class ListMigrationTasksRequest < Struct.new( :next_token, :max_results, :resource_name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken.
725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 725 class ListMigrationTasksRequest < Struct.new( :next_token, :max_results, :resource_name) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
Filter migration tasks by discovered resource name.
725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-migrationhub/types.rb', line 725 class ListMigrationTasksRequest < Struct.new( :next_token, :max_results, :resource_name) SENSITIVE = [] include Aws::Structure end |