Class: Aws::MigrationHub::Types::ListSourceResourcesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-migrationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the response includes a NextToken value, that means that there are more results available. The value of NextToken is a unique pagination token for each page. To retrieve the next page of results, call this API again and specify this NextToken value in the request. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.

Returns:

  • (String)


851
852
853
854
855
856
# File 'lib/aws-sdk-migrationhub/types.rb', line 851

class ListSourceResourcesResult < Struct.new(
  :next_token,
  :source_resource_list)
  SENSITIVE = []
  include Aws::Structure
end

#source_resource_listArray<Types::SourceResource>

The list of source resources.

Returns:



851
852
853
854
855
856
# File 'lib/aws-sdk-migrationhub/types.rb', line 851

class ListSourceResourcesResult < Struct.new(
  :next_token,
  :source_resource_list)
  SENSITIVE = []
  include Aws::Structure
end