Class: Aws::MigrationHub::Types::NotifyApplicationStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-migrationhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The configurationId in Application Discovery Service that uniquely identifies the grouped application.



982
983
984
985
986
987
988
989
# File 'lib/aws-sdk-migrationhub/types.rb', line 982

class NotifyApplicationStateRequest < Struct.new(
  :application_id,
  :status,
  :update_date_time,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call.



982
983
984
985
986
987
988
989
# File 'lib/aws-sdk-migrationhub/types.rb', line 982

class NotifyApplicationStateRequest < Struct.new(
  :application_id,
  :status,
  :update_date_time,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Status of the application - Not Started, In-Progress, Complete.



982
983
984
985
986
987
988
989
# File 'lib/aws-sdk-migrationhub/types.rb', line 982

class NotifyApplicationStateRequest < Struct.new(
  :application_id,
  :status,
  :update_date_time,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#update_date_timeTime

The timestamp when the application state changed.



982
983
984
985
986
987
988
989
# File 'lib/aws-sdk-migrationhub/types.rb', line 982

class NotifyApplicationStateRequest < Struct.new(
  :application_id,
  :status,
  :update_date_time,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end