Class: Aws::MigrationHub::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHub::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhub/client.rb
Overview
An API client for MigrationHub. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MigrationHub::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_created_artifact(params = {}) ⇒ Struct
Associates a created artifact of an AWS cloud resource, the target receiving the migration, with the migration task performed by a migration tool.
-
#associate_discovered_resource(params = {}) ⇒ Struct
Associates a discovered resource ID from Application Discovery Service with a migration task.
-
#associate_source_resource(params = {}) ⇒ Struct
Associates a source resource with a migration task.
-
#create_progress_update_stream(params = {}) ⇒ Struct
Creates a progress update stream which is an AWS resource used for access control as well as a namespace for migration task names that is implicitly linked to your AWS account.
-
#delete_progress_update_stream(params = {}) ⇒ Struct
Deletes a progress update stream, including all of its tasks, which was previously created as an AWS resource used for access control.
-
#describe_application_state(params = {}) ⇒ Types::DescribeApplicationStateResult
Gets the migration status of an application.
-
#describe_migration_task(params = {}) ⇒ Types::DescribeMigrationTaskResult
Retrieves a list of all attributes associated with a specific migration task.
-
#disassociate_created_artifact(params = {}) ⇒ Struct
Disassociates a created artifact of an AWS resource with a migration task performed by a migration tool that was previously associated.
-
#disassociate_discovered_resource(params = {}) ⇒ Struct
Disassociate an Application Discovery Service discovered resource from a migration task.
-
#disassociate_source_resource(params = {}) ⇒ Struct
Removes the association between a source resource and a migration task.
-
#import_migration_task(params = {}) ⇒ Struct
Registers a new migration task which represents a server, database, etc., being migrated to AWS by a migration tool.
-
#list_application_states(params = {}) ⇒ Types::ListApplicationStatesResult
Lists all the migration statuses for your applications.
-
#list_created_artifacts(params = {}) ⇒ Types::ListCreatedArtifactsResult
Lists the created artifacts attached to a given migration task in an update stream.
-
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResult
Lists discovered resources associated with the given ‘MigrationTask`.
-
#list_migration_task_updates(params = {}) ⇒ Types::ListMigrationTaskUpdatesResult
This is a paginated API that returns all the migration-task states for the specified ‘MigrationTaskName` and `ProgressUpdateStream`.
-
#list_migration_tasks(params = {}) ⇒ Types::ListMigrationTasksResult
Lists all, or filtered by resource name, migration tasks associated with the user account making this call.
-
#list_progress_update_streams(params = {}) ⇒ Types::ListProgressUpdateStreamsResult
Lists progress update streams associated with the user account making this call.
-
#list_source_resources(params = {}) ⇒ Types::ListSourceResourcesResult
Lists all the source resource that are associated with the specified ‘MigrationTaskName` and `ProgressUpdateStream`.
-
#notify_application_state(params = {}) ⇒ Struct
Sets the migration state of an application.
-
#notify_migration_task_state(params = {}) ⇒ Struct
Notifies Migration Hub of the current status, progress, or other detail regarding a migration task.
-
#put_resource_attributes(params = {}) ⇒ Struct
Provides identifying details of the resource being migrated so that it can be associated in the Application Discovery Service repository.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1556 1557 1558 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1556 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1559 1560 1561 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1559 def errors_module Errors end |
Instance Method Details
#associate_created_artifact(params = {}) ⇒ Struct
Associates a created artifact of an AWS cloud resource, the target receiving the migration, with the migration task performed by a migration tool. This API has the following traits:
-
Migration tools can call the ‘AssociateCreatedArtifact` operation to indicate which AWS artifact is associated with a migration task.
-
The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example: ‘arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b`.
-
Examples of the AWS resource behind the created artifact are, AMI’s, EC2 instance, or DMS endpoint, etc.
532 533 534 535 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 532 def associate_created_artifact(params = {}, = {}) req = build_request(:associate_created_artifact, params) req.send_request() end |
#associate_discovered_resource(params = {}) ⇒ Struct
Associates a discovered resource ID from Application Discovery Service with a migration task.
572 573 574 575 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 572 def associate_discovered_resource(params = {}, = {}) req = build_request(:associate_discovered_resource, params) req.send_request() end |
#associate_source_resource(params = {}) ⇒ Struct
Associates a source resource with a migration task. For example, the source resource can be a source server, an application, or a migration wave.
621 622 623 624 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 621 def associate_source_resource(params = {}, = {}) req = build_request(:associate_source_resource, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1529 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHub') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhub' context[:gem_version] = '1.88.0' Seahorse::Client::Request.new(handlers, context) end |
#create_progress_update_stream(params = {}) ⇒ Struct
Creates a progress update stream which is an AWS resource used for access control as well as a namespace for migration task names that is implicitly linked to your AWS account. It must uniquely identify the migration tool as it is used for all updates made by the tool; however, it does not need to be unique for each AWS account because it is scoped to the AWS account.
654 655 656 657 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 654 def create_progress_update_stream(params = {}, = {}) req = build_request(:create_progress_update_stream, params) req.send_request() end |
#delete_progress_update_stream(params = {}) ⇒ Struct
Deletes a progress update stream, including all of its tasks, which was previously created as an AWS resource used for access control. This API has the following traits:
-
The only parameter needed for ‘DeleteProgressUpdateStream` is the stream name (same as a `CreateProgressUpdateStream` call).
-
The call will return, and a background process will asynchronously delete the stream and all of its resources (tasks, associated resources, resource attributes, created artifacts).
-
If the stream takes time to be deleted, it might still show up on a ‘ListProgressUpdateStreams` call.
-
‘CreateProgressUpdateStream`, `ImportMigrationTask`, `NotifyMigrationTaskState`, and all Associate APIs related to the tasks belonging to the stream will throw “InvalidInputException” if the stream of the same name is in the process of being deleted.
-
Once the stream and all of its resources are deleted, ‘CreateProgressUpdateStream` for a stream of the same name will succeed, and that stream will be an entirely new logical resource (without any resources associated with the old stream).
705 706 707 708 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 705 def delete_progress_update_stream(params = {}, = {}) req = build_request(:delete_progress_update_stream, params) req.send_request() end |
#describe_application_state(params = {}) ⇒ Types::DescribeApplicationStateResult
Gets the migration status of an application.
736 737 738 739 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 736 def describe_application_state(params = {}, = {}) req = build_request(:describe_application_state, params) req.send_request() end |
#describe_migration_task(params = {}) ⇒ Types::DescribeMigrationTaskResult
Retrieves a list of all attributes associated with a specific migration task.
778 779 780 781 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 778 def describe_migration_task(params = {}, = {}) req = build_request(:describe_migration_task, params) req.send_request() end |
#disassociate_created_artifact(params = {}) ⇒ Struct
Disassociates a created artifact of an AWS resource with a migration task performed by a migration tool that was previously associated. This API has the following traits:
-
A migration user can call the ‘DisassociateCreatedArtifacts` operation to disassociate a created AWS Artifact from a migration task.
-
The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example: ‘arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b`.
-
Examples of the AWS resource behind the created artifact are, AMI’s, EC2 instance, or RDS instance, etc.
830 831 832 833 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 830 def disassociate_created_artifact(params = {}, = {}) req = build_request(:disassociate_created_artifact, params) req.send_request() end |
#disassociate_discovered_resource(params = {}) ⇒ Struct
Disassociate an Application Discovery Service discovered resource from a migration task.
868 869 870 871 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 868 def disassociate_discovered_resource(params = {}, = {}) req = build_request(:disassociate_discovered_resource, params) req.send_request() end |
#disassociate_source_resource(params = {}) ⇒ Struct
Removes the association between a source resource and a migration task.
912 913 914 915 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 912 def disassociate_source_resource(params = {}, = {}) req = build_request(:disassociate_source_resource, params) req.send_request() end |
#import_migration_task(params = {}) ⇒ Struct
Registers a new migration task which represents a server, database, etc., being migrated to AWS by a migration tool.
This API is a prerequisite to calling the ‘NotifyMigrationTaskState` API as the migration tool must first register the migration task with Migration Hub.
949 950 951 952 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 949 def import_migration_task(params = {}, = {}) req = build_request(:import_migration_task, params) req.send_request() end |
#list_application_states(params = {}) ⇒ Types::ListApplicationStatesResult
Lists all the migration statuses for your applications. If you use the optional ‘ApplicationIds` parameter, only the migration statuses for those applications will be returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
997 998 999 1000 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 997 def list_application_states(params = {}, = {}) req = build_request(:list_application_states, params) req.send_request() end |
#list_created_artifacts(params = {}) ⇒ Types::ListCreatedArtifactsResult
Lists the created artifacts attached to a given migration task in an update stream. This API has the following traits:
-
Gets the list of the created artifacts while migration is taking place.
-
Shows the artifacts created by the migration tool that was associated by the ‘AssociateCreatedArtifact` API.
-
Lists created artifacts in a paginated interface.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1055 1056 1057 1058 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1055 def list_created_artifacts(params = {}, = {}) req = build_request(:list_created_artifacts, params) req.send_request() end |
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResult
Lists discovered resources associated with the given ‘MigrationTask`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1104 1105 1106 1107 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1104 def list_discovered_resources(params = {}, = {}) req = build_request(:list_discovered_resources, params) req.send_request() end |
#list_migration_task_updates(params = {}) ⇒ Types::ListMigrationTaskUpdatesResult
This is a paginated API that returns all the migration-task states for the specified ‘MigrationTaskName` and `ProgressUpdateStream`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1169 def list_migration_task_updates(params = {}, = {}) req = build_request(:list_migration_task_updates, params) req.send_request() end |
#list_migration_tasks(params = {}) ⇒ Types::ListMigrationTasksResult
Lists all, or filtered by resource name, migration tasks associated with the user account making this call. This API has the following traits:
-
Can show a summary list of the most recent migration tasks.
-
Can show a summary list of migration tasks associated with a given discovered resource.
-
Lists migration tasks in a paginated interface.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1226 1227 1228 1229 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1226 def list_migration_tasks(params = {}, = {}) req = build_request(:list_migration_tasks, params) req.send_request() end |
#list_progress_update_streams(params = {}) ⇒ Types::ListProgressUpdateStreamsResult
Lists progress update streams associated with the user account making this call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1266 1267 1268 1269 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1266 def list_progress_update_streams(params = {}, = {}) req = build_request(:list_progress_update_streams, params) req.send_request() end |
#list_source_resources(params = {}) ⇒ Types::ListSourceResourcesResult
Lists all the source resource that are associated with the specified ‘MigrationTaskName` and `ProgressUpdateStream`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1329 def list_source_resources(params = {}, = {}) req = build_request(:list_source_resources, params) req.send_request() end |
#notify_application_state(params = {}) ⇒ Struct
Sets the migration state of an application. For a given application identified by the value passed to ‘ApplicationId`, its status is set or updated by passing one of three values to `Status`: `NOT_STARTED | IN_PROGRESS | COMPLETED`.
1368 1369 1370 1371 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1368 def notify_application_state(params = {}, = {}) req = build_request(:notify_application_state, params) req.send_request() end |
#notify_migration_task_state(params = {}) ⇒ Struct
Notifies Migration Hub of the current status, progress, or other detail regarding a migration task. This API has the following traits:
-
Migration tools will call the ‘NotifyMigrationTaskState` API to share the latest progress and status.
-
‘MigrationTaskName` is used for addressing updates to the correct target.
-
‘ProgressUpdateStream` is used for access control and to provide a namespace for each migration tool.
1429 1430 1431 1432 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1429 def notify_migration_task_state(params = {}, = {}) req = build_request(:notify_migration_task_state, params) req.send_request() end |
#put_resource_attributes(params = {}) ⇒ Struct
Provides identifying details of the resource being migrated so that it can be associated in the Application Discovery Service repository. This association occurs asynchronously after ‘PutResourceAttributes` returns.
-
Keep in mind that subsequent calls to PutResourceAttributes will override previously stored attributes. For example, if it is first called with a MAC address, but later, it is desired to add an IP address, it will then be required to call it with both the IP and MAC addresses to prevent overriding the MAC address.
-
Note the instructions regarding the special use case of the [ ‘ResourceAttributeList` ][1] parameter when specifying any “VM” related value.
<note markdown=“1”> Because this is an asynchronous call, it will always return 200, whether an association occurs or not. To confirm if an association was found based on the provided details, call ‘ListDiscoveredResources`.
</note>
1520 1521 1522 1523 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1520 def put_resource_attributes(params = {}, = {}) req = build_request(:put_resource_attributes, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1549 1550 1551 |
# File 'lib/aws-sdk-migrationhub/client.rb', line 1549 def waiter_names [] end |